.. _physics.distribution:

Distribution functions
======================

.. currentmodule:: sisl.physics

Various distributions using different smearing techniques.

.. autosummary::
   :toctree: generated/

   get_distribution
   gaussian
   lorentzian
   fermi_dirac
   bose_einstein
   cold
   step_function
   heaviside
